# Generated by Django 3.0.4 on 2020-03-29 21:03

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_dramatiq_pg", "0001_initial"),
    ]

    operations = [
        migrations.RenameModel("QueuedJob", "BackgroundJob"),
    ]
